- Y
A numerical vector of sample data.
- X
A numerical vector of sample data.
- x
Optional. A scalar or range of points where the density is estimated. If NULL, a range is automatically generated.
- h
A scalar bandwidth parameter. If NULL, the bandwidth is automatically selected using the method specified in 'h_method'.
- h_method
Method for automatic bandwidth selection when h is NULL. Options are "cv" (cross-validation) and "silverman" (Silverman's rule of thumb). Default is "cv".
- alpha
Confidence level for intervals. Default is 0.05.
- est_Ar
Optional list of estimates for A and r. If NULL, they are computed using get_est_Ar().
- resol
Resolution for the estimation range. Default is 100.
- xi_lb
Optional. Lower bound for the interval of Fourier Transform frequency xi. Used for determining the range over which A and r is estimated. If NULL, it is automatically determined based on the methods_get_xi.
- xi_ub
Optional. Upper bound for the interval of Fourier Transform frequency xi. Similar to xi_lb, it defines the upper range for A and r estimation. If NULL, the upper bound is determined based on the methods_get_xi.
- methods_get_xi
A string specifying the method to automatically determine the xi interval if xi_lb and xi_ub are NULL. Options are "Schennach" and "Schennach_loose". If "Schennach" the range is selected based on the Theorem 2 in Schennach2020, if "Schennach_loose", it is defined by the initial interval given in Theorem 2 without selecting the xi_n.
- if_plot_ft
Logical. If TRUE, plots the Fourier transform.
- ora_Ar
Optional list of oracle values for A and r.
- if_plot_conditional_mean
Logical. If TRUE, plots the conditional mean estimation.
- kernel.fun
A string specifying the kernel function to be used. Options are "Schennach2004", "sinc", "normal", "epanechnikov".
- if_approx_kernel
Logical. If TRUE, uses approximations for the kernel function.
- kernel.resol
The resolution for kernel function approximation. See fun_approx.