Create a configuration object for bias bound estimations
create_biasBound_config(
X,
Y = NULL,
h = NULL,
h_method = "cv",
use_fft = TRUE,
alpha = 0.05,
resol = 100,
xi_lb = NULL,
xi_ub = NULL,
methods_get_xi = "Schennach",
kernel.fun = "Schennach2004",
if_approx_kernel = TRUE,
kernel.resol = 1000
)A configuration object (list) with all parameters
A numerical vector of sample data.
Optional. A numerical vector of sample data for conditional expectation.
A scalar bandwidth parameter. If NULL, the bandwidth is automatically selected using the method specified in 'h_method'.
Method for automatic bandwidth selection when h is NULL. Options are "cv" (cross-validation) and "silverman" (Silverman's rule of thumb). Default is "cv".
Ignored. Maintained for backward compatibility.
Confidence level for intervals.
Resolution for the estimation range.
Lower bound for the interval of Fourier Transform frequency.
Upper bound for the interval of Fourier Transform frequency.
Method to determine xi interval.
Kernel function to be used. Options include "normal", "epanechnikov", "Schennach2004", and "sinc".
Use approximations for the kernel function.
Resolution for kernel approximation.