get_avg_f1x: Kernel point estimation
Description
Computes the point estimate using the specified kernel function.
Usage
get_avg_f1x(X, x, h, inf_k)
Value
A scalar representing the kernel density estimate at point x.
Arguments
- X
A numerical vector of sample data.
- x
A scalar representing the point where the density is estimated.
- h
A scalar bandwidth parameter.
- inf_k
Kernel function used for the computation.