Computes the point estimate using the specified kernel function.
get_avg_fyx(Y, X, x, h, inf_k)A scalar representing the kernel density estimate at point x.
A numerical vector representing the sample data of variable Y.
A numerical vector representing the sample data of variable X.
A scalar representing the point where the density is estimated.
A scalar bandwidth parameter.
Kernel function used for the computation.