get_avg_phi_log: Compute log sample average of fourier transform and get mod

View source: R/utils.R

get_avg_phi_logR Documentation

Compute log sample average of fourier transform and get mod

Description

Compute log sample average of fourier transform and get mod

Usage

get_avg_phi_log(Y = 1, X, ln_xi)

Arguments

Y

A numerical vector representing the sample data of variable Y.

X

A numerical vector representing the sample data of variable X.

ln_xi

A single numerical value representing the log frequency at which the Fourier transform is computed.

Value

Returns the log sample estimation of expected Fourier transform at frequency xi.


rbbnp documentation built on June 8, 2025, 10:46 a.m.