| get_est_B | R Documentation |
get the estimation of B
get_est_B(Y)
Y |
A numerical vector representing the sample data of variable Y. |
The mean of the absolute values of the elements in Y, representing the estimated value of B.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.