Computes the bias estimate for given parameters.
get_est_b1x(X, h, est_Ar, inf_k_ft, ...)A scalar representing the bias b1x estimate.
A numerical vector representing the sample data of variable X.
A scalar bandwidth parameter.
A vector containing the estimated A and r parameters.
A kernel Fourier transform function.
Additional arguments passed to the quadgk integration function.