Learn R Programming

rbbnp (version 0.3.0)

get_est_byx: Estimation of bias byx

Description

Estimation of bias byx

Usage

get_est_byx(Y, X, ...)

Value

A scalar representing the bias byx estimate.

Arguments

Y

A numerical vector representing the sample data of variable Y.

X

A numerical vector representing the sample data of variable X.

...

Additional arguments passed to other methods.