Estimation of sigma_yx
get_sigma_yx(Y, X, x, h, inf_k)Returns a scalar representing the estimated value of sigma_yx at the point x. Returns 0 if either fyx or conditional variance is negative.
A numerical vector representing the sample data of variable Y.
A numerical vector representing the sample data of variable X.
The specific point at which sigma_yx is to be estimated.
A bandwidth parameter used in the kernel function for smoothing.
A kernel function used to weigh observations in the neighborhood of point x.