| kernel_reg | R Documentation |
Kernel Regression function
kernel_reg(X, Y, x, h, kernel_func)
X |
A numerical vector representing the sample data of variable X. |
Y |
A numerical vector representing the sample data of variable Y. |
x |
The point at which the regression function is to be estimated. |
h |
A bandwidth parameter that determines the weight assigned to each observation in X. |
kernel_func |
A function that computes the weight of each observation based on its distance to x. |
Returns a scalar representing the estimated value of the regression function at the point x.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.