| sinc_ft | R Documentation |
Define the closed form FT of the infinite order kernel sin(x)/(pi*x)
sinc_ft(x)
x |
A numerical value or vector where the Fourier Transform is evaluated. |
The value of the Fourier Transform of the sinc function at each point in x.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.