powered by
Estimation of bias byx
get_est_byx(Y, X, ...)
A scalar representing the bias byx estimate.
A numerical vector representing the sample data of variable Y.
A numerical vector representing the sample data of variable X.
Additional arguments passed to other methods.